Person Name - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Person Name

A `betty.model.ancestry.PersonName` describes a name for a person.

## Fields

Names inherit from:

- Privacy

`affiliation` (optional `str`)

  The person’s affiliation or family name, their surname, or last name.

`citations` (iterable of Citation)

  The citations for this person.

`id` (`str`)

  The name’s own entity ID.

`individual` (optional `str`)

  The person’s individual or personal name, their first name, or given name.

`locale` (optional `str`)

  The name’s locale as an IETF BCP 47 language tag.

`person` (Person)

  The person whose name this is.